Function to calculate the seasonal centers of biomass of Mid-Atlantic species and map them.
Usage
map_nefsc_cob(species = "all", data = NULL)
Arguments
- species
Default is "all", includes Mid-Atlantic species represented in `species.shift::species_list()`
- data
Default is "nefsc". `pull_nefsc()` must be run prior in order to run this function.
Value
Map of distribution of seasonal centers of biomass along the Northeast US. Selecting `all` species will return a list.
Examples
# map_nefsc_cob(species = "black sea bass", data = nefsc)