Function to calculate and plot the proportion of surveyed biomass in each council region
Usage
plot_council_biomass(species = "all", data = NULL)
Arguments
- species
Default is "all", includes Mid-Atlantic species represented in `species.shift::species_list()`
- data
Default is "nefsc" `nefsc` must be run and named "observer" in order to run this function.
Value
Barplot of biomass proportions across Atlantic council management zones. Selecting `all` species will return a list.
Examples
# plot_council_biomass(species = "summer flounder", data = nefsc)