Function to pull and clean Vessel Trip Reports from pre-existing confidential repository.
Arguments
- proj_path
Local path to data folder. Note that VTR data was provided in multiple CSV files. This function is designed to read all CSV files within a central location. If other CSVs are stored in the same location as the VTR, this function will not be able to discern the different data and will not run.